************
Installation
************

The recommended installation method is using ``pip``.

pip
===

.. code:: bash

    $ pip install spacetrack

To install with :mod:`asyncio` support, install the async extra:

.. code:: bash

    $ pip install spacetrack[async]

Git
===

.. code-block:: sh

   $ git clone https://github.com/python-astrodynamics/spacetrack.git
   Cloning into 'spacetrack'...

Check out a `release tag`_

.. parsed-literal::

   $ cd spacetrack
   $ git checkout |version|

.. _`release tag`: https://github.com/python-astrodynamics/spacetrack/releases
